@@ -13,10 +13,11 @@ use Exporter;
 use strict;
 use vars qw($VERSION @ISA @EXPORT_OK %_callback);
 
-$VERSION = "1.4";
+$VERSION = "1.5";
 @ISA = qw(Exporter DynaLoader);
 @EXPORT_OK = qw(set_callback get_callback rfc822_base64 rfc822_qprint
-	rfc822_date rfc822_parse_adrlist rfc822_write_address rfc822_output);
+		utf8_mime2text rfc822_date rfc822_parse_adrlist
+		rfc822_write_address rfc822_output);
 
 {
 	package Mail::Cclient::Address;
